==> App-GitHooks-Plugin-PrependTicketID-v1.0.1.tar.gz: App-GitHooks-Plugin-PrependTicketID-v1.0.1/README.md <==
App-GitHooks-Plugin-PrependTicketID
===================================

[![Build Status](https://travis-ci.org/guillaumeaubert/App-GitHooks-Plugin-PrependTicketID.png?branch=master)](https://travis-ci.org/guillaumeaubert/App-GitHooks-Plugin-PrependTicketID)
[![Coverage Status](https://coveralls.io/repos/guillaumeaubert/App-GitHooks-Plugin-PrependTicketID/badge.png?branch=master)](https://coveralls.io/r/guillaumeaubert/App-GitHooks-Plugin-PrependTicketID?branch=master)

App::GitHooks plugin to derive a ticket ID from the branch name and prepend it
to the commit-message.


INSTALLATION
------------

To install this module, run the following commands:

	perl Build.PL
	./Build
	./Build test
	./Build install


SUPPORT AND DOCUMENTATION
-------------------------

After installing, you can find documentation for this module with the
perldoc command.

	perldoc App::GitHooks::Plugin::PrependTicketID


You can also look for information at:

 * [GitHub's request tracker (report bugs here)]
   (https://github.com/guillaumeaubert/App-GitHooks-Plugin-PrependTicketID/issues)

 * [AnnoCPAN, Annotated CPAN documentation]
   (http://annocpan.org/dist/App-GitHooks-Plugin-PrependTicketID)

 * [CPAN Ratings]
   (http://cpanratings.perl.org/d/App-GitHooks-Plugin-PrependTicketID)

 * [MetaCPAN]
   (https://metacpan.org/release/App-GitHooks-Plugin-PrependTicketID)


LICENSE AND COPYRIGHT
---------------------

Copyright (C) 2013-2014 Guillaume Aubert

This program is free software: you can redistribute it and/or modify it under
the terms of the GNU General Public License version 3 as published by the Free
Software Foundation.

This program is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
PARTICULAR PURPOSE. See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with
this program. If not, see http://www.gnu.org/licenses/

==> App-GitHooks-Plugin-PrependTicketID-v1.1.0.tar.gz: App-GitHooks-Plugin-PrependTicketID-v1.1.0/README.md <==
App-GitHooks-Plugin-PrependTicketID
===================================

[![Build Status](https://travis-ci.org/guillaumeaubert/App-GitHooks-Plugin-PrependTicketID.svg?branch=master)](https://travis-ci.org/guillaumeaubert/App-GitHooks-Plugin-PrependTicketID)
[![Coverage Status](https://coveralls.io/repos/guillaumeaubert/App-GitHooks-Plugin-PrependTicketID/badge.svg?branch=master)](https://coveralls.io/r/guillaumeaubert/App-GitHooks-Plugin-PrependTicketID?branch=master)
[![Latest Version](https://img.shields.io/github/tag/guillaumeaubert/App-GitHooks-Plugin-PrependTicketID.svg?style=flat)](https://metacpan.org/release/App-GitHooks-Plugin-PrependTicketID)

App::GitHooks plugin to derive a ticket ID from the branch name and prepend it
to the commit-message.


INSTALLATION
------------

To install this module, run the following commands:

	perl Build.PL
	./Build
	./Build test
	./Build install


SUPPORT AND DOCUMENTATION
-------------------------

After installing, you can find documentation for this module with the
perldoc command.

	perldoc App::GitHooks::Plugin::PrependTicketID


You can also look for information at:

 * [GitHub's request tracker (report bugs here)]
   (https://github.com/guillaumeaubert/App-GitHooks-Plugin-PrependTicketID/issues)

 * [AnnoCPAN, Annotated CPAN documentation]
   (http://annocpan.org/dist/App-GitHooks-Plugin-PrependTicketID)

 * [CPAN Ratings]
   (http://cpanratings.perl.org/d/App-GitHooks-Plugin-PrependTicketID)

 * [MetaCPAN]
   (https://metacpan.org/release/App-GitHooks-Plugin-PrependTicketID)


LICENSE AND COPYRIGHT
---------------------

Copyright (C) 2013-2015 Guillaume Aubert

This program is free software: you can redistribute it and/or modify it under
the terms of the GNU General Public License version 3 as published by the Free
Software Foundation.

This program is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
PARTICULAR PURPOSE. See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with
this program. If not, see http://www.gnu.org/licenses/
